@@ -1,5 +1,6 @@
 var NAVTREEINDEX4 =
 {
+"group__pw__pipewire.html#gae7a5b43b7a86b9e79e9b3c3c549bdf65":[8,5,0,6],
 "group__pw__pipewire.html#gaf3d7686492ea5032eb135cddf21d3da2":[8,5,0,15],
 "group__pw__pipewire.html#gafa6045cd7391b467af4575c6752d6c4e":[8,5,0,2],
 "group__pw__pipewire.html#gafb27fefe2f3d0620f973c2c76ae3ba8b":[8,5,0,8],
@@ -248,6 +249,5 @@ var NAVTREEINDEX4 =
 "group__pw__session__manager.html#ga6068d234f2810c9c5eb64be9e1eb3b23":[8,8,4,78],
 "group__pw__session__manager.html#ga60daa7b99b0160772e5b5b8d5696fe54":[8,8,4,177],
 "group__pw__session__manager.html#ga61c63491758436617fc59af4f263b4eb":[8,8,4,64],
-"group__pw__session__manager.html#ga638a14bb21921dcaa09283a76a81f7a5":[8,8,4,150],
-"group__pw__session__manager.html#ga640eb23a56a0f38002b3f7d4ce5ce501":[8,8,4,49]
+"group__pw__session__manager.html#ga638a14bb21921dcaa09283a76a81f7a5":[8,8,4,150]
 };
